@@ -1,7 +1,7 @@
 from . import __shell__
 from .utils import which
 from .utils import mkdir
-from .utils import reg
+from .utils import action
 
 __all__ = ['which', 'mkdir', 'fopen', 'run']
 
