@@ -34,9 +34,27 @@ class User(abstract.User):
 class Package(abstract.Package):
     @executable
     def install(self):
+        '''
+        Installs package system-wide using apt-get
+
+        Example:
+        from alpha.platform import ubuntu
+        ubuntu.Package('packagename').install()
+
+        NOTE: last line performs in shell `apt-get install -y packagename`
+        '''
         return 'apt-get install -y {name}'.format(name=self.name or self.__class__.name)
 
     @executable
     def uninstall(self):
+        '''
+        Uninstalls package system-wide using apt-get
+
+        Example:
+        from alpha.platform import ubuntu
+        ubuntu.Package('packagename').uninstall()
+
+        NOTE: last line performs in shell `apt-get remove -y packagename`
+        '''
         return 'apt-get remove -y {name}'.format(name=self.name or self.__class__.name)
 
