@@ -1,3 +1,5 @@
+import functools
+
 from . import __shell__
 
 def which(executable):
@@ -9,3 +11,11 @@ def mkdir(dir_or_dirs):
         dir_or_dirs = [dir_or_dirs]
     command = '\n'.join(['mkdir -p {}'.format(dirictory) for dirictory in dir_or_dirs])
     return __shell__.run(command)
+
+
+def action(func):
+    func.im_action = True
+    @functools.wraps(func)
+    def wrapper(*args, **kwargs):
+        return func(*args, **kwargs)
+    return wrapper
